Method: LanguageParser::JavaVariable#comment=

Defined in:
lib/cgialib/lp/JavaLanguageScanner.rb

#comment=(text) ⇒ Object

comment=( text )

text - The comment text

Override of the comment set method to not only set the comment but also to parse it into the JavaDoc



41
42
43
44
45
46
47
48
# File 'lib/cgialib/lp/JavaLanguageScanner.rb', line 41

def comment=( text )
  
super( text )
  
  @javadoc = @javadocClass.new() unless ( @javadoc )
  @javadoc.parse( text )
  
end